@@ -17,8 +17,10 @@
 #include <QtConcurrent/qtconcurrentreducekernel.h>
 #include <QtConcurrent/qtconcurrentrunbase.h>
 #include <QtConcurrent/qtconcurrentthreadengine.h>
+#if QT_CONFIG(future)
 #include <QtCore/qfuture.h>
 #include <QtCore/qfuturewatcher.h>
+#endif
 // Type indices
 enum : int {
     SBK_QFUTUREQSTRING_IDX                                   = 1,
@@ -67,10 +69,18 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+#if QT_CONFIG(future)
 template<> inline PyTypeObject *SbkType< ::QFutureQString >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtConcurrentTypes[SBK_QFUTUREQSTRING_IDX]); }
+#endif
+#if QT_CONFIG(future)
 template<> inline PyTypeObject *SbkType< ::QFutureVoid >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtConcurrentTypes[SBK_QFUTUREVOID_IDX]); }
+#endif
+#if QT_CONFIG(future)
 template<> inline PyTypeObject *SbkType< ::QFutureWatcherQString >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtConcurrentTypes[SBK_QFUTUREWATCHERQSTRING_IDX]); }
+#endif
+#if QT_CONFIG(future)
 template<> inline PyTypeObject *SbkType< ::QFutureWatcherVoid >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtConcurrentTypes[SBK_QFUTUREWATCHERVOID_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QtConcurrent::ThreadFunctionResult >() { return SbkPySide6_QtConcurrentTypes[SBK_QTCONCURRENT_THREADFUNCTIONRESULT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QtConcurrent::ReduceOption >() { return SbkPySide6_QtConcurrentTypes[SBK_QTCONCURRENT_REDUCEOPTION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QtConcurrent::ReduceOption> >() { return SbkPySide6_QtConcurrentTypes[SBK_QFLAGS_QTCONCURRENT_REDUCEOPTION_IDX]; }
