@@ -16,7 +16,6 @@
 // Bound library includes
 #include <QtNetwork/qabstractsocket.h>
 #include <QtNetwork/qdnslookup.h>
-#include <QtNetwork/qdtls.h>
 #include <QtNetwork/qhostaddress.h>
 #include <QtNetwork/qhostinfo.h>
 #include <QtNetwork/qhstspolicy.h>
@@ -26,18 +25,26 @@
 #include <QtNetwork/qnetworkaccessmanager.h>
 #include <QtNetwork/qnetworkcookie.h>
 #include <QtNetwork/qnetworkinformation.h>
-#include <QtNetwork/qnetworkinterface.h>
 #include <QtNetwork/qnetworkproxy.h>
 #include <QtNetwork/qnetworkreply.h>
 #include <QtNetwork/qnetworkrequest.h>
-#include <QtNetwork/qocspresponse.h>
 #include <QtNetwork/qpassworddigestor.h>
 #include <QtNetwork/qssl.h>
+#if QT_CONFIG(dtls)
+#include <QtNetwork/qdtls.h>
+#endif
+#if QT_CONFIG(ssl)
+#include <QtNetwork/qdtls.h>
+#include <QtNetwork/qocspresponse.h>
 #include <QtNetwork/qsslcertificate.h>
 #include <QtNetwork/qsslconfiguration.h>
 #include <QtNetwork/qssldiffiehellmanparameters.h>
 #include <QtNetwork/qsslerror.h>
 #include <QtNetwork/qsslsocket.h>
+#endif
+#ifndef QT_NO_NETWORKINTERFACE
+#include <QtNetwork/qnetworkinterface.h>
+#endif
 class QAbstractNetworkCache;
 class QAuthenticator;
 class QDnsDomainNameRecord;
@@ -242,9 +249,15 @@ namespace Shiboken
 {
 
 // PyType functions, to get the PyObjectType for a type T
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QDtlsError >() { return SbkPySide6_QtNetworkTypes[SBK_QDTLSERROR_IDX]; }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QOcspCertificateStatus >() { return SbkPySide6_QtNetworkTypes[SBK_QOCSPCERTIFICATESTATUS_IDX]; }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QOcspRevocationReason >() { return SbkPySide6_QtNetworkTypes[SBK_QOCSPREVOCATIONREASON_IDX]; }
+#endif
 template<> inline PyTypeObject *SbkType< ::QAbstractNetworkCache >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QABSTRACTNETWORKCACHE_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QAbstractSocket::SocketType >() { return SbkPySide6_QtNetworkTypes[SBK_QABSTRACTSOCKET_SOCKETTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QAbstractSocket::NetworkLayerProtocol >() { return SbkPySide6_QtNetworkTypes[SBK_QABSTRACTSOCKET_NETWORKLAYERPROTOCOL_IDX]; }
@@ -265,9 +278,13 @@ template<> inline PyTypeObject *SbkType< ::QDnsLookup >() { return reinterpret_c
 template<> inline PyTypeObject *SbkType< ::QDnsMailExchangeRecord >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDNSMAILEXCHANGERECORD_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDnsServiceRecord >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDNSSERVICERECORD_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QDnsTextRecord >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDNSTEXTRECORD_IDX]); }
+#if QT_CONFIG(dtls)
 template<> inline PyTypeObject *SbkType< ::QDtls::HandshakeState >() { return SbkPySide6_QtNetworkTypes[SBK_QDTLS_HANDSHAKESTATE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QDtls >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDTLS_IDX]); }
+#endif
+#if QT_CONFIG(dtls)
 template<> inline PyTypeObject *SbkType< ::QDtlsClientVerifier >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QDTLSCLIENTVERIFIER_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QHostAddress::SpecialAddress >() { return SbkPySide6_QtNetworkTypes[SBK_QHOSTADDRESS_SPECIALADDRESS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QHostAddress::ConversionModeFlag >() { return SbkPySide6_QtNetworkTypes[SBK_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QHostAddress::ConversionModeFlag> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QHOSTADDRESS_CONVERSIONMODEFLAG_IDX]; }
@@ -292,8 +309,10 @@ template<> inline PyTypeObject *SbkType< ::QFlags<QLocalSocket::SocketOption> >(
 template<> inline PyTypeObject *SbkType< ::QLocalSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QLOCALSOCKET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager::Operation >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_OPERATION_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkAccessManager >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKACCESSMANAGER_IDX]); }
+#ifndef QT_NO_NETWORKINTERFACE
 template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry::DnsEligibilityStatus >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKADDRESSENTRY_DNSELIGIBILITYSTATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkAddressEntry >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKADDRESSENTRY_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QNetworkCacheMetaData >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKCACHEMETADATA_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QNetworkCookie::RawForm >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKCOOKIE_RAWFORM_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkCookie::SameSite >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKCOOKIE_SAMESITE_IDX]; }
@@ -306,10 +325,12 @@ template<> inline PyTypeObject *SbkType< ::QNetworkInformation::TransportMedium
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation::Feature >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_FEATURE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInformation::Feature> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QNETWORKINFORMATION_FEATURE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkInformation >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKINFORMATION_IDX]); }
+#ifndef QT_NO_NETWORKINTERFACE
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceFlag >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINTERFACE_INTERFACEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkInterface::InterfaceFlag> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QNETWORKINTERFACE_INTERFACEFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface::InterfaceType >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKINTERFACE_INTERFACETYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkInterface >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKINTERFACE_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QNetworkProxy::ProxyType >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKPROXY_PROXYTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkProxy::Capability >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKPROXY_CAPABILITY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QFlags<QNetworkProxy::Capability> >() { return SbkPySide6_QtNetworkTypes[SBK_QFLAGS_QNETWORKPROXY_CAPABILITY_IDX]; }
@@ -327,7 +348,9 @@ template<> inline PyTypeObject *SbkType< ::QNetworkRequest::Priority >() { retur
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::RedirectPolicy >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKREQUEST_REDIRECTPOLICY_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest::TransferTimeoutConstant >() { return SbkPySide6_QtNetworkTypes[SBK_QNETWORKREQUEST_TRANSFERTIMEOUTCONSTANT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QNetworkRequest >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QNETWORKREQUEST_IDX]); }
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QOcspResponse >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QOCSPRESPONSE_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QSsl::KeyType >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_KEYTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSsl::EncodingFormat >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_ENCODINGFORMAT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSsl::KeyAlgorithm >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_KEYALGORITHM_IDX]; }
@@ -339,24 +362,44 @@ template<> inline PyTypeObject *SbkType< ::QSsl::AlertLevel >() { return SbkPySi
 template<> inline PyTypeObject *SbkType< ::QSsl::AlertType >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_ALERTTYPE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSsl::ImplementedClass >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_IMPLEMENTEDCLASS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSsl::SupportedFeature >() { return SbkPySide6_QtNetworkTypes[SBK_QSSL_SUPPORTEDFEATURE_IDX]; }
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslCertificate::SubjectInfo >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLCERTIFICATE_SUBJECTINFO_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate::PatternSyntax >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLCERTIFICATE_PATTERNSYNTAX_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslCertificate >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLCERTIFICATE_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslCertificateExtension >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLCERTIFICATEEXTENSION_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslCipher >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLCIPHER_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslConfiguration::NextProtocolNegotiationStatus >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLCONFIGURATION_NEXTPROTOCOLNEGOTIATIONSTATUS_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslConfiguration >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLCONFIGURATION_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslDiffieHellmanParameters::Error >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLDIFFIEHELLMANPARAMETERS_ERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslDiffieHellmanParameters >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLDIFFIEHELLMANPARAMETERS_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslEllipticCurve >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLELLIPTICCURVE_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslError::SslError >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLERROR_SSLERROR_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslError >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLERROR_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QSslKey >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLKEY_IDX]); }
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslPreSharedKeyAuthenticator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLPRESHAREDKEYAUTHENTICATOR_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslServer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLSERVER_IDX]); }
+#endif
+#if QT_CONFIG(ssl)
 template<> inline PyTypeObject *SbkType< ::QSslSocket::SslMode >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLSOCKET_SSLMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslSocket::PeerVerifyMode >() { return SbkPySide6_QtNetworkTypes[SBK_QSSLSOCKET_PEERVERIFYMODE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QSslSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QSSLSOCKET_IDX]); }
+#endif
 template<> inline PyTypeObject *SbkType< ::QTcpServer >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QTCPSERVER_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QTcpSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QTCPSOCKET_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QUdpSocket >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtNetworkTypes[SBK_QUDPSOCKET_IDX]); }
