@@ -17,30 +17,33 @@
 // Bound library includes
 #include <QtPdf/qpdfbookmarkmodel.h>
 #include <QtPdf/qpdfdocument.h>
+#include <QtPdf/qpdfdocumentrenderoptions.h>
 #include <QtPdf/qpdfpagerenderer.h>
 #include <QtPdf/qpdfsearchmodel.h>
-class QPdfDocumentRenderOptions;
 class QPdfLink;
 class QPdfPageNavigator;
 class QPdfSelection;
 // Type indices
 enum : int {
-    SBK_QPDFBOOKMARKMODEL_ROLE_IDX                           = 2,
-    SBK_QPDFBOOKMARKMODEL_IDX                                = 1,
-    SBK_QPDFDOCUMENT_STATUS_IDX                              = 7,
-    SBK_QPDFDOCUMENT_ERROR_IDX                               = 4,
-    SBK_QPDFDOCUMENT_METADATAFIELD_IDX                       = 5,
-    SBK_QPDFDOCUMENT_PAGEMODELROLE_IDX                       = 6,
-    SBK_QPDFDOCUMENT_IDX                                     = 3,
-    SBK_QPDFDOCUMENTRENDEROPTIONS_IDX                        = 8,
-    SBK_QPDFLINK_IDX                                         = 9,
-    SBK_QPDFPAGENAVIGATOR_IDX                                = 10,
-    SBK_QPDFPAGERENDERER_RENDERMODE_IDX                      = 12,
-    SBK_QPDFPAGERENDERER_IDX                                 = 11,
-    SBK_QPDFSEARCHMODEL_ROLE_IDX                             = 14,
-    SBK_QPDFSEARCHMODEL_IDX                                  = 13,
-    SBK_QPDFSELECTION_IDX                                    = 15,
-    SBK_QtPdf_IDX_COUNT                                      = 16
+    SBK_QPDFBOOKMARKMODEL_ROLE_IDX                           = 3,
+    SBK_QPDFBOOKMARKMODEL_IDX                                = 2,
+    SBK_QPDFDOCUMENT_STATUS_IDX                              = 8,
+    SBK_QPDFDOCUMENT_ERROR_IDX                               = 5,
+    SBK_QPDFDOCUMENT_METADATAFIELD_IDX                       = 6,
+    SBK_QPDFDOCUMENT_PAGEMODELROLE_IDX                       = 7,
+    SBK_QPDFDOCUMENT_IDX                                     = 4,
+    SBK_QPDFDOCUMENTRENDEROPTIONS_ROTATION_IDX               = 11,
+    SBK_QPDFDOCUMENTRENDEROPTIONS_RENDERFLAG_IDX             = 10,
+    SBK_QFLAGS_QPDFDOCUMENTRENDEROPTIONS_RENDERFLAG_IDX      = 0,
+    SBK_QPDFDOCUMENTRENDEROPTIONS_IDX                        = 9,
+    SBK_QPDFLINK_IDX                                         = 12,
+    SBK_QPDFPAGENAVIGATOR_IDX                                = 13,
+    SBK_QPDFPAGERENDERER_RENDERMODE_IDX                      = 15,
+    SBK_QPDFPAGERENDERER_IDX                                 = 14,
+    SBK_QPDFSEARCHMODEL_ROLE_IDX                             = 17,
+    SBK_QPDFSEARCHMODEL_IDX                                  = 16,
+    SBK_QPDFSELECTION_IDX                                    = 18,
+    SBK_QtPdf_IDX_COUNT                                      = 19
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtPdfTypes;
@@ -83,6 +86,9 @@ template<> inline PyTypeObject *SbkType< ::QPdfDocument::Error >() { return SbkP
 template<> inline PyTypeObject *SbkType< ::QPdfDocument::MetaDataField >() { return SbkPySide6_QtPdfTypes[SBK_QPDFDOCUMENT_METADATAFIELD_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QPdfDocument::PageModelRole >() { return SbkPySide6_QtPdfTypes[SBK_QPDFDOCUMENT_PAGEMODELROLE_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QPdfDocument >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtPdfTypes[SBK_QPDFDOCUMENT_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QPdfDocumentRenderOptions::Rotation >() { return SbkPySide6_QtPdfTypes[SBK_QPDFDOCUMENTRENDEROPTIONS_ROTATION_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QPdfDocumentRenderOptions::RenderFlag >() { return SbkPySide6_QtPdfTypes[SBK_QPDFDOCUMENTRENDEROPTIONS_RENDERFLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QPdfDocumentRenderOptions::RenderFlag> >() { return SbkPySide6_QtPdfTypes[SBK_QFLAGS_QPDFDOCUMENTRENDEROPTIONS_RENDERFLAG_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QPdfDocumentRenderOptions >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtPdfTypes[SBK_QPDFDOCUMENTRENDEROPTIONS_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPdfLink >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtPdfTypes[SBK_QPDFLINK_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QPdfPageNavigator >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtPdfTypes[SBK_QPDFPAGENAVIGATOR_IDX]); }
