@@ -23,6 +23,7 @@
 #include <QtWebEngineCore/qwebenginecontextmenurequest.h>
 #include <QtWebEngineCore/qwebenginecookiestore.h>
 #include <QtWebEngineCore/qwebenginedownloadrequest.h>
+#include <QtWebEngineCore/qwebenginefilesystemaccessrequest.h>
 #include <QtWebEngineCore/qwebenginehistory.h>
 #include <QtWebEngineCore/qwebenginehttprequest.h>
 #include <QtWebEngineCore/qwebengineloadinginfo.h>
@@ -46,73 +47,77 @@ class QWebEngineUrlRequestInterceptor;
 class QWebEngineUrlSchemeHandler;
 // Type indices
 enum : int {
-    SBK_QWEBENGINECERTIFICATEERROR_TYPE_IDX                  = 5,
-    SBK_QWEBENGINECERTIFICATEERROR_IDX                       = 4,
-    SBK_QWEBENGINECONTEXTMENUREQUEST_MEDIATYPE_IDX           = 9,
-    SBK_QWEBENGINECONTEXTMENUREQUEST_MEDIAFLAG_IDX           = 8,
+    SBK_QWEBENGINECERTIFICATEERROR_TYPE_IDX                  = 6,
+    SBK_QWEBENGINECERTIFICATEERROR_IDX                       = 5,
+    SBK_QWEBENGINECONTEXTMENUREQUEST_MEDIATYPE_IDX           = 10,
+    SBK_QWEBENGINECONTEXTMENUREQUEST_MEDIAFLAG_IDX           = 9,
     SBK_QFLAGS_QWEBENGINECONTEXTMENUREQUEST_MEDIAFLAG_IDX    = 1,
-    SBK_QWEBENGINECONTEXTMENUREQUEST_EDITFLAG_IDX            = 7,
+    SBK_QWEBENGINECONTEXTMENUREQUEST_EDITFLAG_IDX            = 8,
     SBK_QFLAGS_QWEBENGINECONTEXTMENUREQUEST_EDITFLAG_IDX     = 0,
-    SBK_QWEBENGINECONTEXTMENUREQUEST_IDX                     = 6,
-    SBK_QWEBENGINECOOKIESTORE_IDX                            = 10,
-    SBK_QWEBENGINECOOKIESTORE_FILTERREQUEST_IDX              = 11,
-    SBK_QWEBENGINEDOWNLOADREQUEST_DOWNLOADSTATE_IDX          = 14,
-    SBK_QWEBENGINEDOWNLOADREQUEST_SAVEPAGEFORMAT_IDX         = 15,
-    SBK_QWEBENGINEDOWNLOADREQUEST_DOWNLOADINTERRUPTREASON_IDX = 13,
-    SBK_QWEBENGINEDOWNLOADREQUEST_IDX                        = 12,
-    SBK_QWEBENGINEFINDTEXTRESULT_IDX                         = 16,
-    SBK_QWEBENGINEFULLSCREENREQUEST_IDX                      = 17,
-    SBK_QWEBENGINEHISTORY_IDX                                = 18,
-    SBK_QWEBENGINEHISTORYITEM_IDX                            = 19,
-    SBK_QWEBENGINEHISTORYMODEL_ROLES_IDX                     = 21,
-    SBK_QWEBENGINEHISTORYMODEL_IDX                           = 20,
-    SBK_QWEBENGINEHTTPREQUEST_METHOD_IDX                     = 23,
-    SBK_QWEBENGINEHTTPREQUEST_IDX                            = 22,
-    SBK_QWEBENGINELOADINGINFO_LOADSTATUS_IDX                 = 26,
-    SBK_QWEBENGINELOADINGINFO_ERRORDOMAIN_IDX                = 25,
-    SBK_QWEBENGINELOADINGINFO_IDX                            = 24,
-    SBK_QWEBENGINENEWWINDOWREQUEST_DESTINATIONTYPE_IDX       = 28,
-    SBK_QWEBENGINENEWWINDOWREQUEST_IDX                       = 27,
-    SBK_QWEBENGINENOTIFICATION_IDX                           = 29,
-    SBK_QWEBENGINEPAGE_WEBACTION_IDX                         = 39,
-    SBK_QWEBENGINEPAGE_FINDFLAG_IDX                          = 33,
-    SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX                   = 2,
-    SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX                     = 40,
-    SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX                  = 37,
-    SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX                    = 36,
-    SBK_QWEBENGINEPAGE_FEATURE_IDX                           = 31,
-    SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX                 = 32,
-    SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX     = 34,
-    SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX    = 38,
-    SBK_QWEBENGINEPAGE_LIFECYCLESTATE_IDX                    = 35,
-    SBK_QWEBENGINEPAGE_IDX                                   = 30,
-    SBK_QWEBENGINEPROFILE_HTTPCACHETYPE_IDX                  = 42,
-    SBK_QWEBENGINEPROFILE_PERSISTENTCOOKIESPOLICY_IDX        = 43,
-    SBK_QWEBENGINEPROFILE_IDX                                = 41,
-    SBK_QWEBENGINEQUOTAREQUEST_IDX                           = 44,
-    SBK_QWEBENGINEREGISTERPROTOCOLHANDLERREQUEST_IDX         = 45,
-    SBK_QWEBENGINESCRIPT_INJECTIONPOINT_IDX                  = 47,
-    SBK_QWEBENGINESCRIPT_SCRIPTWORLDID_IDX                   = 48,
-    SBK_QWEBENGINESCRIPT_IDX                                 = 46,
-    SBK_QWEBENGINESCRIPTCOLLECTION_IDX                       = 49,
-    SBK_QWEBENGINESETTINGS_FONTFAMILY_IDX                    = 51,
-    SBK_QWEBENGINESETTINGS_WEBATTRIBUTE_IDX                  = 54,
-    SBK_QWEBENGINESETTINGS_FONTSIZE_IDX                      = 52,
-    SBK_QWEBENGINESETTINGS_UNKNOWNURLSCHEMEPOLICY_IDX        = 53,
-    SBK_QWEBENGINESETTINGS_IDX                               = 50,
-    SBK_QWEBENGINEURLREQUESTINFO_RESOURCETYPE_IDX            = 57,
-    SBK_QWEBENGINEURLREQUESTINFO_NAVIGATIONTYPE_IDX          = 56,
-    SBK_QWEBENGINEURLREQUESTINFO_IDX                         = 55,
-    SBK_QWEBENGINEURLREQUESTINTERCEPTOR_IDX                  = 58,
-    SBK_QWEBENGINEURLREQUESTJOB_ERROR_IDX                    = 60,
-    SBK_QWEBENGINEURLREQUESTJOB_IDX                          = 59,
-    SBK_QWEBENGINEURLSCHEME_SYNTAX_IDX                       = 64,
-    SBK_QWEBENGINEURLSCHEME_SPECIALPORT_IDX                  = 63,
-    SBK_QWEBENGINEURLSCHEME_FLAG_IDX                         = 62,
-    SBK_QFLAGS_QWEBENGINEURLSCHEME_FLAG_IDX                  = 3,
-    SBK_QWEBENGINEURLSCHEME_IDX                              = 61,
-    SBK_QWEBENGINEURLSCHEMEHANDLER_IDX                       = 65,
-    SBK_QtWebEngineCore_IDX_COUNT                            = 66
+    SBK_QWEBENGINECONTEXTMENUREQUEST_IDX                     = 7,
+    SBK_QWEBENGINECOOKIESTORE_IDX                            = 11,
+    SBK_QWEBENGINECOOKIESTORE_FILTERREQUEST_IDX              = 12,
+    SBK_QWEBENGINEDOWNLOADREQUEST_DOWNLOADSTATE_IDX          = 15,
+    SBK_QWEBENGINEDOWNLOADREQUEST_SAVEPAGEFORMAT_IDX         = 16,
+    SBK_QWEBENGINEDOWNLOADREQUEST_DOWNLOADINTERRUPTREASON_IDX = 14,
+    SBK_QWEBENGINEDOWNLOADREQUEST_IDX                        = 13,
+    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_HANDLETYPE_IDX     = 19,
+    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_ACCESSFLAG_IDX     = 18,
+    SBK_QFLAGS_QWEBENGINEFILESYSTEMACCESSREQUEST_ACCESSFLAG_IDX = 2,
+    SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_IDX                = 17,
+    SBK_QWEBENGINEFINDTEXTRESULT_IDX                         = 20,
+    SBK_QWEBENGINEFULLSCREENREQUEST_IDX                      = 21,
+    SBK_QWEBENGINEHISTORY_IDX                                = 22,
+    SBK_QWEBENGINEHISTORYITEM_IDX                            = 23,
+    SBK_QWEBENGINEHISTORYMODEL_ROLES_IDX                     = 25,
+    SBK_QWEBENGINEHISTORYMODEL_IDX                           = 24,
+    SBK_QWEBENGINEHTTPREQUEST_METHOD_IDX                     = 27,
+    SBK_QWEBENGINEHTTPREQUEST_IDX                            = 26,
+    SBK_QWEBENGINELOADINGINFO_LOADSTATUS_IDX                 = 30,
+    SBK_QWEBENGINELOADINGINFO_ERRORDOMAIN_IDX                = 29,
+    SBK_QWEBENGINELOADINGINFO_IDX                            = 28,
+    SBK_QWEBENGINENEWWINDOWREQUEST_DESTINATIONTYPE_IDX       = 32,
+    SBK_QWEBENGINENEWWINDOWREQUEST_IDX                       = 31,
+    SBK_QWEBENGINENOTIFICATION_IDX                           = 33,
+    SBK_QWEBENGINEPAGE_WEBACTION_IDX                         = 43,
+    SBK_QWEBENGINEPAGE_FINDFLAG_IDX                          = 37,
+    SBK_QFLAGS_QWEBENGINEPAGE_FINDFLAG_IDX                   = 3,
+    SBK_QWEBENGINEPAGE_WEBWINDOWTYPE_IDX                     = 44,
+    SBK_QWEBENGINEPAGE_PERMISSIONPOLICY_IDX                  = 41,
+    SBK_QWEBENGINEPAGE_NAVIGATIONTYPE_IDX                    = 40,
+    SBK_QWEBENGINEPAGE_FEATURE_IDX                           = 35,
+    SBK_QWEBENGINEPAGE_FILESELECTIONMODE_IDX                 = 36,
+    SBK_QWEBENGINEPAGE_JAVASCRIPTCONSOLEMESSAGELEVEL_IDX     = 38,
+    SBK_QWEBENGINEPAGE_RENDERPROCESSTERMINATIONSTATUS_IDX    = 42,
+    SBK_QWEBENGINEPAGE_LIFECYCLESTATE_IDX                    = 39,
+    SBK_QWEBENGINEPAGE_IDX                                   = 34,
+    SBK_QWEBENGINEPROFILE_HTTPCACHETYPE_IDX                  = 46,
+    SBK_QWEBENGINEPROFILE_PERSISTENTCOOKIESPOLICY_IDX        = 47,
+    SBK_QWEBENGINEPROFILE_IDX                                = 45,
+    SBK_QWEBENGINEQUOTAREQUEST_IDX                           = 48,
+    SBK_QWEBENGINEREGISTERPROTOCOLHANDLERREQUEST_IDX         = 49,
+    SBK_QWEBENGINESCRIPT_INJECTIONPOINT_IDX                  = 51,
+    SBK_QWEBENGINESCRIPT_SCRIPTWORLDID_IDX                   = 52,
+    SBK_QWEBENGINESCRIPT_IDX                                 = 50,
+    SBK_QWEBENGINESCRIPTCOLLECTION_IDX                       = 53,
+    SBK_QWEBENGINESETTINGS_FONTFAMILY_IDX                    = 55,
+    SBK_QWEBENGINESETTINGS_WEBATTRIBUTE_IDX                  = 58,
+    SBK_QWEBENGINESETTINGS_FONTSIZE_IDX                      = 56,
+    SBK_QWEBENGINESETTINGS_UNKNOWNURLSCHEMEPOLICY_IDX        = 57,
+    SBK_QWEBENGINESETTINGS_IDX                               = 54,
+    SBK_QWEBENGINEURLREQUESTINFO_RESOURCETYPE_IDX            = 61,
+    SBK_QWEBENGINEURLREQUESTINFO_NAVIGATIONTYPE_IDX          = 60,
+    SBK_QWEBENGINEURLREQUESTINFO_IDX                         = 59,
+    SBK_QWEBENGINEURLREQUESTINTERCEPTOR_IDX                  = 62,
+    SBK_QWEBENGINEURLREQUESTJOB_ERROR_IDX                    = 64,
+    SBK_QWEBENGINEURLREQUESTJOB_IDX                          = 63,
+    SBK_QWEBENGINEURLSCHEME_SYNTAX_IDX                       = 68,
+    SBK_QWEBENGINEURLSCHEME_SPECIALPORT_IDX                  = 67,
+    SBK_QWEBENGINEURLSCHEME_FLAG_IDX                         = 66,
+    SBK_QFLAGS_QWEBENGINEURLSCHEME_FLAG_IDX                  = 4,
+    SBK_QWEBENGINEURLSCHEME_IDX                              = 65,
+    SBK_QWEBENGINEURLSCHEMEHANDLER_IDX                       = 69,
+    SBK_QtWebEngineCore_IDX_COUNT                            = 70
 };
 // This variable stores all Python types exported by this module.
 extern PyTypeObject **SbkPySide6_QtWebEngineCoreTypes;
@@ -126,21 +131,22 @@ extern SbkConverter **SbkPySide6_QtWebEngineCoreTypeConverters;
 // Converter indices
 enum : int {
     SBK_QTWEBENGINECORE_QLIST_INT_IDX                        = 0, // QList<int >
-    SBK_QTWEBENGINECORE_QLIST_QWEBENGINESCRIPT_IDX           = 1, // QList<QWebEngineScript >
-    SBK_QTWEBENGINECORE_QLIST_QSSLCERTIFICATE_IDX            = 2, // QList<QSslCertificate >
-    SBK_QTWEBENGINECORE_QLIST_QOBJECTPTR_IDX                 = 3, // QList<QObject* >
-    SBK_QTWEBENGINECORE_QLIST_QBYTEARRAY_IDX                 = 4, // QList<QByteArray >
-    SBK_QTWEBENGINECORE_QMAP_QBYTEARRAY_QBYTEARRAY_IDX       = 5, // QMap<QByteArray,QByteArray >
-    SBK_QTWEBENGINECORE_QLIST_QURL_IDX                       = 6, // QList<QUrl >
-    SBK_QTWEBENGINECORE_QLIST_QWEBENGINEHISTORYITEM_IDX      = 7, // QList<QWebEngineHistoryItem >
-    SBK_QTWEBENGINECORE_QMAP_QSTRING_QSTRING_IDX             = 8, // QMap<QString,QString >
-    SBK_QTWEBENGINECORE_QMAP_INT_QVARIANT_IDX                = 9, // QMap<int,QVariant >
-    SBK_QTWEBENGINECORE_QLIST_QMODELINDEX_IDX                = 10, // QList<QModelIndex >
-    SBK_QTWEBENGINECORE_QHASH_INT_QBYTEARRAY_IDX             = 11, // QHash<int,QByteArray >
-    SBK_QTWEBENGINECORE_QLIST_QVARIANT_IDX                   = 12, // QList<QVariant >
-    SBK_QTWEBENGINECORE_QLIST_QSTRING_IDX                    = 13, // QList<QString >
-    SBK_QTWEBENGINECORE_QMAP_QSTRING_QVARIANT_IDX            = 14, // QMap<QString,QVariant >
-    SBK_QtWebEngineCore_CONVERTERS_IDX_COUNT                 = 15
+    SBK_QTWEBENGINECORE_QHASH_QBYTEARRAY_QBYTEARRAY_IDX      = 1, // QHash<QByteArray,QByteArray >
+    SBK_QTWEBENGINECORE_QLIST_QWEBENGINESCRIPT_IDX           = 2, // QList<QWebEngineScript >
+    SBK_QTWEBENGINECORE_QLIST_QSSLCERTIFICATE_IDX            = 3, // QList<QSslCertificate >
+    SBK_QTWEBENGINECORE_QLIST_QOBJECTPTR_IDX                 = 4, // QList<QObject* >
+    SBK_QTWEBENGINECORE_QLIST_QBYTEARRAY_IDX                 = 5, // QList<QByteArray >
+    SBK_QTWEBENGINECORE_QMAP_QBYTEARRAY_QBYTEARRAY_IDX       = 6, // QMap<QByteArray,QByteArray >
+    SBK_QTWEBENGINECORE_QLIST_QURL_IDX                       = 7, // QList<QUrl >
+    SBK_QTWEBENGINECORE_QLIST_QWEBENGINEHISTORYITEM_IDX      = 8, // QList<QWebEngineHistoryItem >
+    SBK_QTWEBENGINECORE_QMAP_QSTRING_QSTRING_IDX             = 9, // QMap<QString,QString >
+    SBK_QTWEBENGINECORE_QMAP_INT_QVARIANT_IDX                = 10, // QMap<int,QVariant >
+    SBK_QTWEBENGINECORE_QLIST_QMODELINDEX_IDX                = 11, // QList<QModelIndex >
+    SBK_QTWEBENGINECORE_QHASH_INT_QBYTEARRAY_IDX             = 12, // QHash<int,QByteArray >
+    SBK_QTWEBENGINECORE_QLIST_QVARIANT_IDX                   = 13, // QList<QVariant >
+    SBK_QTWEBENGINECORE_QLIST_QSTRING_IDX                    = 14, // QList<QString >
+    SBK_QTWEBENGINECORE_QMAP_QSTRING_QVARIANT_IDX            = 15, // QMap<QString,QVariant >
+    SBK_QtWebEngineCore_CONVERTERS_IDX_COUNT                 = 16
 };
 // Macros for type check
 
@@ -164,6 +170,10 @@ template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest::DownloadSt
 template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest::SavePageFormat >() { return SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEDOWNLOADREQUEST_SAVEPAGEFORMAT_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest::DownloadInterruptReason >() { return SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEDOWNLOADREQUEST_DOWNLOADINTERRUPTREASON_IDX]; }
 template<> inline PyTypeObject *SbkType< ::QWebEngineDownloadRequest >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEDOWNLOADREQUEST_IDX]); }
+template<> inline PyTypeObject *SbkType< ::QWebEngineFileSystemAccessRequest::HandleType >() { return SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_HANDLETYPE_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QWebEngineFileSystemAccessRequest::AccessFlag >() { return SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_ACCESSFLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QFlags<QWebEngineFileSystemAccessRequest::AccessFlag> >() { return SbkPySide6_QtWebEngineCoreTypes[SBK_QFLAGS_QWEBENGINEFILESYSTEMACCESSREQUEST_ACCESSFLAG_IDX]; }
+template<> inline PyTypeObject *SbkType< ::QWebEngineFileSystemAccessRequest >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEFILESYSTEMACCESSREQUEST_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWebEngineFindTextResult >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEFINDTEXTRESULT_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWebEngineFullScreenRequest >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEFULLSCREENREQUEST_IDX]); }
 template<> inline PyTypeObject *SbkType< ::QWebEngineHistory >() { return reinterpret_cast<PyTypeObject *>(SbkPySide6_QtWebEngineCoreTypes[SBK_QWEBENGINEHISTORY_IDX]); }
